/* REXX
 *
 * del_ea.cmd deletes extended attributes of all files of the
 * specified path.
 *
 * Error codes: 0 - success
 *              1 - usage
 *              2 - calculation of temporary file for eas failed
 *              3 - eautil execution failed
 *              4 - deletion of temporary file failed
 */

call RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
call SysLoadFuncs

parse arg sourcepath

if LENGTH(sourcepath) = 0 then
do
   SAY
   SAY 'Dieses Programm entfernt alle EAs von allen Dateien eines'
   SAY 'anzugebenden Verzeichnisses. Eine Dateisuchmaske wie fr dir'
   SAY 'kann zustzlich angegeben werden.'
   SAY
   SAY 'Fehler: Arbeitsverzeichnis nicht angegeben.'
   SAY
   SAY 'Syntax: del_ea.cmd <Arbeitsverzeichnis mit optionaler Suchmaske>'
   SAY
   SAY '        Beispiele: del_ea.cmd x:\Bilder\*.jpg (fr .jpg Bilder)'
   SAY '                   del_ea.cmd x:\Bilder       (fr alle Dateien)'
   exit 1
end

/****************************** Execute ****************************/

/* Find all files by pattern. */
call SysFileTree sourcepath, 'filenames', 'SO'
  
/* Calculate temporary file for EAs. */
tempfile = SysTempFileName('eas.???')
if LENGTH(tempfile) = 0 then
do
   SAY 'Fehler bei der Bestimmung des temporren Dateinames fr die EAs.'
   exit 2
end

/* Check if any files were found. */
if filenames.0 > 0 then
do
   SAY

   /* Remove EAs */
   do i=1 to filenames.0
      say filenames.i
      '@eautil 'filenames.i tempfile' /S /R'
      if rc != 0 then
      do
         SAY
         SAY 'Fehler beim Lschen der EAs aufgetreten.'
         exit 3
      end
   end

   /* Delete temporary file if created. */
   rc = SysFileDelete(tempfile)
   if rc != 0 then
   do
      /* It's OK if file was not found. (probably not created by eautil)
       * All other error will be reported.
       */
      if rc != 2 then
      do
         SAY
         SAY 'Fehler beim Lschen der temporren EA-Datei aufgetreten.'
         exit 4
      end
   end
end
else
do
   SAY
   SAY 'Keine entsprechenden Dateien gefunden.'
end

SAY
SAY 'Operation beendet.'
exit 0

