/* REXX
 *
 * del_ea.cmd deletes extended attributes of all files of the
 * specified path.
 *
 * Error codes: 0 - success
 *              1 - usage
 *              2 - calculation of temporary file for eas failed
 *              3 - eautil execution failed
 *              4 - deletion of temporary file failed
 */

call RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
call SysLoadFuncs

parse arg sourcepath

if LENGTH(sourcepath) = 0 then
do
   SAY
   SAY 'This program removes all EAs from all files of a specified directory.'
   SAY 'A filemask like for the dir command can be optionally added.'
   SAY
   SAY 'Error: Working directory not specified.'
   SAY
   SAY 'Syntax: del_ea.cmd <working directory with optional filemask>'
   SAY
   SAY '        Examples: del_ea.cmd x:\images\*.jpg (for .jpg images)'
   SAY '                  del_ea.cmd x:\images       (for all files)'
   exit 1
end

/****************************** Execute ****************************/

/* Find all files by pattern. */
call SysFileTree sourcepath, 'filenames', 'SO'
  
/* Calculate temporary file for EAs. */
tempfile = SysTempFileName('eas.???')
if LENGTH(tempfile) = 0 then
do
   SAY 'Error during calculation of the temporary file name for the EAs.'
   exit 2
end

/* Check if any files were found. */
if filenames.0 > 0 then
do
   SAY

   /* Remove EAs */
   do i=1 to filenames.0
      say filenames.i
      '@eautil 'filenames.i tempfile' /S /R'
      if rc != 0 then
      do
         SAY
         SAY 'Error during removing EAs.'
         exit 3
      end
   end

   /* Delete temporary file if created. */
   rc = SysFileDelete(tempfile)
   if rc != 0 then
   do
      /* It's OK if file was not found. (probably not created by eautil)
       * All other error will be reported.
       */
      if rc != 2 then
      do
         SAY
         SAY 'Error during deleting the temporary EA file.'
         exit 4
      end
   end
end
else
do
   SAY
   SAY 'No matching files found.'
end

SAY
SAY 'Operation complete.'
exit 0

